ch.rs.pvalue(x, type, lag1, S, n, nobsreg, VMdf)"dummy" for seasonal dummies or "trigonometric" for seasonal cycles.For type="dummy",
the p-value for the joint test statistic is not available.
This function is mainly intended to be used internally by ch.test.
ch.test.