Learn R Programming

uroot (version 1.1)

rmg: Range mean plot

Description

Plot of range against mean.

Usage

rmg (vari, krmg)

Arguments

vari
a ts object.
krmg
the number of observations employed for calculating each point.

Value

  • Shows a plot of the range against the mean, correlation between the range and the mean.

Details

In order to ensure that enough observations are employed for calculating each point, it may choose a choose a value of krmg based on the number of observations T, for example: sqrt(T).

Examples

Run this code
data(AirPassengers)
     rmg (vari=AirPassengers, sqrt(length(AirPassengers)))

Run the code above in your browser using DataLab