hegy.rs.pvalue(x, type = c("zero", "pi", "pair", "seasall", "all"), deterministic = c(1, 0, 0), lag.method = c("fixed", "AIC", "BIC"), lag.order, S, n, nobsreg)The original source includes tables with coefficients for the calculation of p-values when the HQC lag order selection criterion is used. These tables are not included here.
The case with no deterministic terms (deterministic = c(0,0,0)) is not considered.
This function is mainly intended to be used internally by hegy.test.
hegy.test.