the number of observations employed for calculating each point.
Value
Shows a plot of the range against the mean, correlation between the range and the mean.
Details
In order to ensure that enough observations are employed for calculating each point,
it may choose a choose a value of krmg based on the number of observations T, for example: sqrt(T).